Welcome to django-crudbuilder’s documentation! — django-crudbuilder 0.0.8 documentation

# Welcome to django-crudbuilder’s documentation!

## Contents:

- Overview
  - Features
  - Requirements and Compatibility
- Installation and Usage
  - Generating CRUD class based views
  - CRUD Model Attributes
- Additional Settings
  - LOGIN_REQUIRED_FOR_CRUD
  - PERMISSION_REQUIRED_FOR_CRUD
- Signals
  - post_create_signal
  - post_update_signal

## Issues:

Use the GitHub issue tracker for django-crudbuilder to submit bugs, issues, and feature requests.